/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "HTMLLabelElement.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomHTMLElement.h"
#include "gdom/GdomHTMLLabelElement.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomHTMLElement.h"
#include "gdom/PrivateGdomHTMLLabelElement.h"
#include "gdom/PrivateIntGdomHTMLLabelElement.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMHTMLLabelElement::GDOMHTMLLabelElement(PassRefPtr<WebCore::HTMLLabelElement> impl)
    : GDOMHTMLElement(impl)
{
}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "HTMLLabelElement.h"
#include <gdom/GdomHTMLLabelElement.h>
#include <gdom/PrivateGdomHTMLLabelElement.h>
#include <gdom/PrivateIntGdomHTMLLabelElement.h>
#include <gdom/GdomHTMLLabelElementprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomHTMLLabelElement, gdom_html_label_element, GDOM_TYPE_HTML_ELEMENT);

/*
struct _GdomHTMLLabelElementPrivate {
    class WebCore::HTMLLabelElement *item;
};

#define GDOM_HTML_LABEL_ELEMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_HTML_LABEL_ELEMENT, GdomHTMLLabelElementPrivate))
*/
G_END_DECLS
WebCore::HTMLLabelElement *
gdom_html_label_element_get_private(GdomHTMLLabelElement *request)
{
    GDOMHTMLLabelElement *res;
    res = static_cast<GDOMHTMLLabelElement*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::HTMLLabelElement*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_FORM,
    PROP_ACCESS_KEY,
    PROP_HTML_FOR,
};


static void gdom_html_label_element_finalize(GObject* object)
{
    /*GdomHTMLLabelElement* request = GDOM_HTML_LABEL_ELEMENT(object);*/
    /*GdomHTMLLabelElementPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_HTML_ELEMENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_html_label_element_parent_class)->finalize(object);
}

static void gdom_html_label_element__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLLabelElement *self = GDOM_HTML_LABEL_ELEMENT(object);
    WebCore::HTMLLabelElement * gself = (gdom_html_label_element_get_private(self));
    switch (prop_id) {
     case PROP_ACCESS_KEY:
    {
         gself->setAccessKey(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_HTML_FOR:
    {
         gself->setHtmlFor(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_label_element__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLLabelElement *self = GDOM_HTML_LABEL_ELEMENT(object);
    WebCore::HTMLLabelElement * gself = (gdom_html_label_element_get_private(self));
    switch (prop_id) {
    case PROP_FORM:
    {
         PassRefPtr<WebCore::HTMLFormElement> ptr = gself->form();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_ACCESS_KEY:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->accessKey()));
         break;
    }
    case PROP_HTML_FOR:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->htmlFor()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_label_element_class_init(GdomHTMLLabelElementClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_html_label_element_finalize;
    g_klass->set_property = gdom_html_label_element__set_property_fn;
    g_klass->get_property = gdom_html_label_element__get_property_fn;

    g_object_class_install_property (g_klass, PROP_FORM,
            g_param_spec_object ("form", /* name */
                "html_label_element_form", /* short description */
                "read-only  GdomHTMLFormElement * HTMLLabelElement.form", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_HTML_FORM_ELEMENT, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_ACCESS_KEY,
            g_param_spec_string ("access_key", /* name */
                "html_label_element_access_key", /* short description */
                "read-write  gchar * HTMLLabelElement.access_key", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_HTML_FOR,
            g_param_spec_string ("html_for", /* name */
                "html_label_element_html_for", /* short description */
                "read-write  gchar * HTMLLabelElement.html_for", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomHTMLLabelElementPrivate));*/
}

static void gdom_html_label_element_init(GdomHTMLLabelElement* request)
{
    /*GdomHTMLLabelElementPrivate* priv = GDOM_HTML_LABEL_ELEMENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

